@@ -1,3 +1,4 @@
+import asyncio
 from dataclasses import dataclass
 from typing import Coroutine
 from etsy_apiv3.utils import EtsySession, Response
@@ -51,9 +52,10 @@ class ReceiptResource:
         
         return Receipt(**json)
 
-    async def aget_receipt_by_id(self, shop_id: int, receipt_id: int) -> Coroutine:
+    async def aget_receipt_by_id(self, shop_id: int, receipt_id: int) -> Receipt:
         endpoint = f"shops/{shop_id}/receipts/{receipt_id}"
-        json = self.session.async_request(endpoint=endpoint)
+        task = asyncio.create_task(self.session.async_request(endpoint=endpoint))
+        json = await asyncio.gather(task)
         return Receipt(**json)
     
     def create_shipment(self, shop_id: int, receipt_id: int, tracking_number: str, carrier_name: str, send_bcc: bool = True, note_to_buyer: str = "") -> Receipt:
