@@ -12,6 +12,9 @@ class EtsySession:
     def __token_updater(self, token):
         return token
 
+    async def __async_token_saver(self, token):
+        return token
+    
     def __init__(self,
                  client_key: str,
                  client_secret: str,
@@ -57,7 +60,7 @@ class EtsySession:
         }
 
         session = AsyncOAuth2Session(self.CLIENT_KEY, token=self.TOKEN, auto_refresh_kwargs=refresh_kwargs,
-                                auto_refresh_url=self.__refresh_url, token_updater=self.token_updater
+                                auto_refresh_url=self.__refresh_url, token_updater=self.__async_token_saver
                                 )
         return session
     
